@@ -7,10 +7,7 @@ Usage::
     import boto3
     from mypy_boto3_secretsmanager import SecretsManagerClient
 
-    session = boto3.Session()
-
     client: SecretsManagerClient = boto3.client("secretsmanager")
-    session_client: SecretsManagerClient = session.client("secretsmanager")
     ```
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
