@@ -7,7 +7,7 @@ Usage::
     import boto3
 
     from mypy_boto3_secretsmanager import SecretsManagerClient
-    from mypy_boto3_secretsmanager import (
+    from mypy_boto3_secretsmanager.paginator import (
         ListSecretsPaginator,
     )
 
